from django.contrib import admin
from simple_history.admin import SimpleHistoryAdmin


class PassageAdmin(SimpleHistoryAdmin):
    list_display = ("pk", "get_reference", "get_authors")
    list_display_links = ("pk", "get_reference")
    ordering = ("book__number", "fragment", "sub_fragment")
    list_filter = ("book__number",)
    search_fields = ("descriptions__description",)
    autocomplete_fields = ("descriptions", "authors", "keywords", "cities")
    fields = (
        "descriptions",
        "creator",
        "last_editor",
        "cities",
        # 'authors',
        "book",
        "fragment",
        "sub_fragment",
        "keywords",
        "alternative_urns",
    )

    def get_reference(self, obj):
        return f"{obj.book.number}.{obj.fragment}{obj.sub_fragment}"

    get_reference.short_description = "Passage"

    def get_authors(self, obj):
        return ", ".join(obj.authors.all().values_list("names__name", flat=True))

    get_authors.short_description = "Authors"
