from django.db import models
from django_extensions.db.fields.json import JSONField

from .abstract import AbstractEditableResource, AbstractValidableResource, AbstractUniqueIdentifier


class Alignment(AbstractEditableResource, AbstractValidableResource, AbstractUniqueIdentifier, models.Model):
    """Alignment model

    Represents the M2M relationship between two texts.
    The alignment data is in JSON format.

    """

    text_1 = models.ForeignKey(
        "meleager.Text",
        blank=True,
        null=True,
        on_delete=models.DO_NOTHING,
        related_name="%(app_label)s_%(class)s_text_1",
        related_query_name="%(app_label)s_%(class)ss_text_1",
        help_text="The first text, if null, the text is missing (deleted)",
    )

    text_2 = models.ForeignKey(
        "meleager.Text",
        blank=True,
        null=True,
        on_delete=models.DO_NOTHING,
        related_name="%(app_label)s_%(class)s_text_2",
        related_query_name="%(app_label)s_%(class)ss_text_2",
        help_text="The second text, if null, the text is missing (deleted)",
    )

    alignment_data = JSONField(help_text="The alpheios alignment json.")

    class Meta(AbstractValidableResource.Meta):
        pass
