from django.db import models
from django.template.defaultfilters import truncatewords

from .helpers import Language
from .abstract import AbstractEditableResource, AbstractValidableResource, AbstractUniqueIdentifier


class CommentTextAnchor(models.Model):
    text = models.ForeignKey('meleager.Text', on_delete=models.CASCADE, null=False)
    comment = models.ForeignKey(
        'meleager.Comment', on_delete=models.CASCADE, null=False
    )
    anchor_word = models.CharField(max_length=255, default=" ", null=False)
    occurrence = models.IntegerField(default=0)


class Text(AbstractEditableResource, AbstractValidableResource, AbstractUniqueIdentifier, models.Model):
    class Status(models.IntegerChoices):
        DRAFT = 0
        PUBLISHED = 1
        DELETED = 2

    language = models.ForeignKey(
        'meleager.Language', on_delete=models.SET_DEFAULT, null=False, default='und'
    )

    edition = models.ForeignKey(
        "meleager.Edition",
        on_delete=models.CASCADE,
        null=True,
        blank=True,
        help_text="The edition of this text.",
    )

    status = models.IntegerField(choices=Status.choices, default=Status.PUBLISHED)
    text = models.TextField(help_text="The string of this text")

    comments = models.ManyToManyField(
        "meleager.Comment",
        related_name="texts",
        help_text="The comments of this resource.",
        through=CommentTextAnchor,
    )

    def __str__(self):
        return f"Text ({truncatewords(self.text, 5)})"
