from rest_framework import serializers
from rest_framework.reverse import reverse

from meleager.models import Passage
from .author import AuthorSerializer
from .book import BookSerializer
from .keyword import MinimalLinkedKeywordSerializer


class PassageHyperlink(serializers.HyperlinkedIdentityField):
    def get_url(self, obj, view_name, request, format):
        url_kwargs = {
            'book': obj.book.number,
            'fragment': obj.fragment,
            'sub_fragment': obj.sub_fragment,
        }
        return self.reverse(
            view_name, kwargs=url_kwargs, request=request, format=format
        )


class PassageSerializer(serializers.HyperlinkedModelSerializer):
    url = PassageHyperlink(view_name="passage-detail")
    authors = AuthorSerializer(many=True)
    book = BookSerializer()
    texts = serializers.HyperlinkedRelatedField(
        many=True, read_only=True, view_name="text-detail"
    )
    keywords = MinimalLinkedKeywordSerializer(many=True)
    scholia = serializers.HyperlinkedRelatedField(
        many=True,
        read_only=True,
        view_name="scholium-detail",
    )

    class Meta:
        model = Passage
        fields = ['url', 'authors', 'book', 'texts', 'keywords', 'scholia']
        # ['keywords', 'texts''alternative_uris', 'external_references', 'internal_references']
