import re
from django.urls import include, path, re_path
from rest_framework import routers

from .viewsets.author import AuthorViewSet
from .viewsets.book import BookViewSet
from .viewsets.city import CityViewSet
from .viewsets.comment import CommentViewSet
from .viewsets.description import DescriptionViewSet
from .viewsets.edition import EditionViewSet
from .viewsets.language import LanguageViewSet
from .viewsets.keywords import KeywordCategoryViewSet, KeywordViewSet
from .viewsets.media import ManuscriptViewSet, MediaViewSet
from .viewsets.name import NameViewSet
from .viewsets.passage import PassageViewSet
from .viewsets.scholium import ScholiumViewSet
from .viewsets.text import TextViewSet
from .viewsets.urn import URNViewSet
from .viewsets.user import UserViewSet
from .viewsets.work import WorkViewSet


class MeleagerAPIRouter(routers.DefaultRouter):
    """ Custom router - adjust passage URLs to use URNs """

    def get_lookup_regex(self, viewset, lookup_prefix=''):
        out = super().get_lookup_regex(viewset, lookup_prefix)

        if viewset is PassageViewSet:
            out = "urn:cts:greekLit:tlg7000.tlg001.ag:(?P<book>\d+).(?P<fragment>\d+)(?P<sub_fragment>[^/.]*)"

        return out


router = MeleagerAPIRouter()

router.register(r"passages", PassageViewSet, basename="passage")
router.register(r"works", WorkViewSet, basename="work")
router.register(r"books", BookViewSet, basename="book")
router.register(r"scholia", ScholiumViewSet, basename="scholium")
router.register(r"texts", TextViewSet, basename="text")
router.register(r"media", MediaViewSet, basename="medium")
router.register(r"manuscripts", ManuscriptViewSet, basename="manuscript")
router.register(r"keywords", KeywordViewSet, basename="keyword")
router.register(r"keyword_categories", KeywordCategoryViewSet, basename="keyword_cat")
router.register(r"languages", LanguageViewSet, basename="language")
router.register(r"descriptions", DescriptionViewSet, basename="description")
router.register(r"cities", CityViewSet, basename="city")
router.register(r"authors", AuthorViewSet, basename="author")
router.register(r"comments", CommentViewSet, basename="comment")
router.register(r"users", UserViewSet, basename="user")
router.register(r"urns", URNViewSet, basename="urn")
router.register(r"editions", EditionViewSet, basename="edition")
router.register(r"names", NameViewSet, basename="name")

urlpatterns = router.urls
