from django import template

register = template.Library()


@register.filter
def has_attach_permission(user):
    """All authenticated users can attach an instance to a Passage/Scholium."""
    if user is None:
        return False
    return user.is_authenticated


@register.filter
def has_detach_permission(user, attachment):
    """Only users creators of the given attachment or staff."""
    if user is None:
        return False
    # TODO: make the correct check, using AuthorPassage intermediate
    # model for instance, for the moment we use the dummy permission
    # to still be able to detach an object during our tests.
    # It will probably require to pass the `obj=attachment` parameter.
    is_attachment_creator = user.has_perm("meleager.can_create_mlgr_content")
    return (user.is_authenticated and is_attachment_creator) or user.is_staff


@register.filter
def has_create_permission(user):
    """All authenticated users can create an instance of Comment/Description/etc."""
    if user is None:
        return False
    return user.has_perm("meleager.can_create_mlgr_content")


@register.filter
def has_update_permission(user, instance):
    """Only users creators of the given instance or staff."""
    if user is None:
        return False
    # TODO: check permission related to the given instance.
    return user.has_perm("meleager.can_create_mlgr_content") or user.is_staff


@register.filter
def has_delete_permission(user, instance):
    """Only users creators of the given instance or staff."""
    if user is None:
        return False
    # TODO: check permission related to the given instance.
    return user.has_perm("meleager.can_create_mlgr_content") or user.is_staff
