from django.test import TestCase
from meleager.models import City, Name, Passage


class PassageCityFormsTest(TestCase):
    fixtures = ["test_data.json"]

    @classmethod
    def setUpTestData(cls):
        # Create new author
        cls.new_city = City.objects.create()
        cls.new_city.names.add(
            Name.objects.create(name="test_passage_city_form", language_id="eng")
        )
        cls.passage = Passage.objects.last()
        cls.passage_url = f"{cls.passage.get_absolute_url()}#cities"

    def test_anonymous_user_add_form_redirect(self):
        resp = self.client.post(f"/cities/passage/{self.passage.pk}/create/")
        self.assertRedirects(resp, f"/auth/login/?next=/cities/passage/{self.passage.pk}/create/")

    def test_regular_user_post_city_passage_form(self):
        self.client.login(username="editor", password="editor")

        resp = self.client.post(f"/cities/passage/{self.passage.pk}/create/", {"city": self.new_city.pk})
        self.assertRedirects(resp, self.passage_url)

        self.assertEquals(self.passage.cities.count(), 2)
        self.assertIn(self.new_city, self.passage.cities.all())

    def test_anonymous_user_delete_form_redirect(self):
        self.passage.cities.add(self.new_city)
        resp = self.client.post(f"/cities/passage/{self.passage.pk}/delete/{self.new_city.pk}/")
        self.assertRedirects(
            resp, f"/auth/login/?next=/cities/passage/{self.passage.pk}/delete/{self.new_city.pk}/"
        )

    def test_editor_delete_city_passage_form(self):
        self.client.login(username="editor", password="editor")

        self.passage.cities.add(self.new_city)

        resp = self.client.post(f"/cities/passage/{self.passage.pk}/delete/{self.new_city.pk}/")
        self.assertRedirects(resp, self.passage_url)
        self.assertEquals(self.passage.cities.count(), 1)
