from django.test import TestCase
from django.urls import reverse
from meleager.models import Passage


class MarkdownDescriptionsTest(TestCase):
    fixtures = ["test_data.json"]

    @classmethod
    def setUpTestData(cls):
        cls.passage = Passage.objects.first()
        cls.passage.descriptions.clear()

    def setUp(self):
        self.client.login(username="editor", password="editor")

    def test_render_description(self):
        self.client.post(
            reverse("web:passage-description-create", args=(self.passage.pk,)),
            data={
                "description": """
# Main title

A list:

* foo
* bar

## Second title

Something **strong** and with *emphasis*.
                """,
                "language": "eng",
            },
        )

        first_description = self.passage.descriptions.first()
        self.assertEquals(
            first_description.description_html(),
            """<h3>Main title</h3>
<p>A list:</p>
<ul>
<li>foo</li>
<li>bar</li>
</ul>
<h4>Second title</h4>
<p>Something <strong>strong</strong> and with <em>emphasis</em>.</p>""",
        )

    def test_render_description_not_in_whitelist(self):
        self.client.post(
            reverse("web:passage-description-create", args=(self.passage.pk,)),
            data={
                "description": """
[a link](http://example.org)
<script>evilness</script>
                """,
                "language": "eng",
            },
        )

        first_description = self.passage.descriptions.first()
        self.assertEquals(
            first_description.description_html(),
            """<p>a link</p>\nevilness""",
        )
