from django.shortcuts import redirect, reverse
from django.views import generic

from meleager.models import Manuscript, Passage, Scholium

from ..forms.passage import AddManuscriptForm
from .mixins import AddContentPermReqMixin


class PassageManuscriptCreate(AddContentPermReqMixin, generic.detail.SingleObjectMixin, generic.FormView):
    model = Passage
    pk_url_kwarg = "passage_pk"
    context_object_name = "passage"
    form_class = AddManuscriptForm
    template_name = "web/manuscript/manuscript_create.html"

    def get_context_data(self, **kwargs):
        self.object = self.get_object()
        context = super().get_context_data(**kwargs)
        context["create_url"] = reverse(
            "web:passage-manuscript-create",
            kwargs={"passage_pk": self.kwargs.get("passage_pk")},
        )
        return context

    def form_valid(self, form):
        manuscript = Manuscript.objects.create(
            title=form.cleaned_data["title"],
            url=form.cleaned_data["url"],
        )
        manuscript.save()
        self.get_object().manuscripts.add(manuscript)
        return super().form_valid(form)

    def get_success_url(self):
        return f"{self.get_object().get_absolute_url()}#manuscripts"


class ScholiumManuscriptCreate(AddContentPermReqMixin, generic.detail.SingleObjectMixin, generic.FormView):
    model = Scholium
    pk_url_kwarg = "scholium_pk"
    context_object_name = "scholium"
    form_class = AddManuscriptForm
    template_name = "web/manuscript/manuscript_create.html"

    def get_context_data(self, **kwargs):
        self.object = self.get_object()
        context = super().get_context_data(**kwargs)
        context["create_url"] = reverse(
            "web:scholium-manuscript-create",
            kwargs={"scholium_pk": self.kwargs.get("scholium_pk")},
        )
        return context

    def form_valid(self, form):
        manuscript = Manuscript.objects.create(
            title=form.cleaned_data["title"],
            url=form.cleaned_data["url"],
        )
        manuscript.save()
        self.get_object().manuscripts.add(manuscript)
        return super().form_valid(form)
        
    def get_success_url(self):
        return f"{self.get_object().get_absolute_url()}#manuscripts"
