from django.shortcuts import redirect, reverse
from django.views import generic
from meleager.models import Description, Passage

from .mixins import (
    AddContentPermReqMixin,
    DescriptionCreateMixin,
    RemoveContentPermReqMixin,
)


class PassageDescriptionCreate(DescriptionCreateMixin):
    model = Passage
    context_object_name = "passage"
    pk_url_kwarg = "passage_pk"

    def get_context_data(self, **kwargs):
        self.object = self.get_object()
        context = super().get_context_data(**kwargs)
        context["create_url"] = reverse(
            "web:passage-description-create",
            kwargs={"passage_pk": self.kwargs.get("passage_pk")},
        )
        return context

    def form_valid(self, form):
        self.new_object = self.create_associate_from_form(form)
        return super().form_valid(form)

    def get_success_url(self):
        return (
            f"{self.get_object().get_absolute_url()}#description-{self.new_object.pk}"
        )


class PassageDescriptionUpdate(AddContentPermReqMixin, generic.UpdateView):
    model = Description
    template_name = "web/description/description_update.html"
    pk_url_kwarg = "description_pk"
    fields = ("description", "language")

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context["passage"] = Passage.objects.get(pk=self.kwargs.get("passage_pk"))
        context["update_url"] = reverse(
            "web:passage-description-update",
            kwargs={
                "passage_pk": self.kwargs.get("passage_pk"),
                "description_pk": self.kwargs.get("description_pk"),
            },
        )
        return context

    def get_success_url(self):
        passage = Passage.objects.get(pk=self.kwargs.get("passage_pk"))
        return f"{passage.get_absolute_url()}#description-{self.get_object().pk}"


class PassageDescriptionDelete(RemoveContentPermReqMixin, generic.DetailView):
    model = Description
    template_name = "web/description/description_delete.html"
    pk_url_kwarg = "description_pk"
    context_object_name = "description"

    def get_context_data(self, **kwargs):
        context = super().get_context_data(**kwargs)
        context["passage"] = self.get_object().meleager_passage.first()
        context["delete_url"] = reverse(
            "web:passage-description-delete",
            kwargs={
                "passage_pk": self.kwargs.get("passage_pk"),
                "description_pk": self.kwargs.get("description_pk"),
            },
        )

        return context

    def post(self, request, *args, **kwargs):
        passage = self.get_object().meleager_passage.first()
        self.get_object().delete()
        return redirect(f"{passage.get_absolute_url()}#descriptions")
