from django.shortcuts import redirect, reverse

from meleager.models import Passage, Scholium

from .mixins import TextCreateMixin


class PassageTextCreate(TextCreateMixin):
    model = Passage
    context_object_name = "passage"
    pk_url_kwarg = "passage_pk"

    def get_context_data(self, **kwargs):
        self.object = self.get_object()
        context = super().get_context_data(**kwargs)
        context["passage"] = self.get_object()
        context["create_url"] = reverse(
            "web:passage-text-create",
            kwargs={"passage_pk": self.kwargs.get("passage_pk")},
        )
        return context

    def form_valid(self, form):
        passage = self.get_object()
        text = form.save()
        passage.texts.add(text)
        return redirect(f"{passage.get_absolute_url()}#texts")


class ScholiumTextCreate(TextCreateMixin):
    model = Scholium
    context_object_name = "scholium"
    pk_url_kwarg = "scholium_pk"

    def get_context_data(self, **kwargs):
        self.object = self.get_object()
        context = super().get_context_data(**kwargs)
        context["scholium"] = self.get_object()
        context["create_url"] = reverse(
            "web:scholium-text-create",
            kwargs={"scholium_pk": self.kwargs.get("scholium_pk")},
        )
        return context

    def form_valid(self, form):
        scholium = self.get_object()
        text = form.save()
        scholium.texts.add(text)
        return redirect(f"{scholium.get_absolute_url()}#texts")
